@@ -2,9 +2,8 @@
  *  Copyright (C) 2002 - 2007 Tomasz Kojm <tkojm@clamav.net>
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -98,7 +97,7 @@ void virusaction(const char *filename, const char *virname, const struct cfgstru
 void virusaction(const char *filename, const char *virname, const struct cfgstruct *copt)
 {
 	pid_t pid;
-	struct cfgstruct *cpt;
+	const struct cfgstruct *cpt;
 
     if(!(cpt = cfgopt(copt, "VirusEvent"))->enabled)
 	return;
