@@ -2,9 +2,8 @@
  *  Copyright (C) 2002 - 2006 Tomasz Kojm <tkojm@clamav.net>
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -55,8 +54,6 @@
 #include "shared/output.h"
 #include "shared/misc.h"
 
-#include "libclamav/lockdb.h"
-
 #include "execute.h"
 #include "manager.h"
 #include "mirman.h"
@@ -153,7 +150,7 @@ static void help(void)
 static int download(const struct cfgstruct *copt, const struct optstruct *opt, const char *datadir)
 {
 	int ret = 0, try = 0, maxattempts = 0;
-	struct cfgstruct *cpt;
+	const struct cfgstruct *cpt;
 
 
     maxattempts = cfgopt(copt, "MaxAttempts")->numarg;
@@ -163,17 +160,8 @@ static int download(const struct cfgstruct *copt, const struct optstruct *opt, c
 	logg("^You must specify at least one database mirror.\n");
 	return 56;
     } else {
-	while(cli_writelockdb(datadir, 0) == CL_ELOCKDB) {
-            logg("*Waiting to lock database directory: %s\n", datadir);
-	    sleep(5);
-	    if(++try > 12) {
-		logg("!Can't lock database directory: %s\n", datadir);
-		return 61; 
-	    }
-	}
-	try = 0;
 	while(cpt) {
-	    ret = downloadmanager(copt, opt, cpt->strarg);
+	    ret = downloadmanager(copt, opt, cpt->strarg, datadir);
 	    alarm(0);
 
 	    if(ret == 52 || ret == 54 || ret == 58 || ret == 59) {
@@ -192,11 +180,9 @@ static int download(const struct cfgstruct *copt, const struct optstruct *opt, c
 		}
 
 	    } else {
-		cli_unlockdb(datadir);
 		return ret;
 	    }
 	}
-	cli_unlockdb(datadir);
     }
 
     return ret;
@@ -207,7 +193,8 @@ int main(int argc, char **argv)
 	int ret = 52;
 	const char *newdir, *cfgfile;
 	char *pidfile = NULL;
-	struct cfgstruct *copt, *cpt;
+	struct cfgstruct *copt;
+	const struct cfgstruct *cpt;
 #ifndef	C_WINDOWS
 	struct sigaction sigact;
 	struct sigaction oldact;
@@ -284,6 +271,8 @@ int main(int argc, char **argv)
 #ifdef C_WINDOWS
     if(!pthread_win32_process_attach_np()) {
 	mprintf("!Can't start the win32 pthreads layer\n");
+	opt_free(opt);
+	freecfg(copt);
 	return 63;
     }
 #endif
@@ -295,6 +284,7 @@ int main(int argc, char **argv)
 	if(stat(cfgfile, &statbuf) == -1) {
 	    logg("^Can't stat %s (critical error)\n", cfgfile);
 	    opt_free(opt);
+	    freecfg(copt);
 	    return 56;
 	}
 
@@ -302,6 +292,7 @@ int main(int argc, char **argv)
 	if(statbuf.st_mode & (S_IRGRP | S_IWGRP | S_IXGRP | S_IROTH | S_IWOTH | S_IXOTH)) {
 	    logg("^Insecure permissions (for HTTPProxyPassword): %s must have no more than 0700 permissions.\n", cfgfile);
 	    opt_free(opt);
+	    freecfg(copt);
 	    return 56;
 	}
 #endif
@@ -318,6 +309,7 @@ int main(int argc, char **argv)
 	if((user = getpwnam(unpuser)) == NULL) {
 	    logg("^Can't get information about user %s.\n", unpuser);
 	    opt_free(opt);
+	    freecfg(copt);
 	    return 60;
 	}
 
@@ -326,6 +318,7 @@ int main(int argc, char **argv)
 	    if(initgroups(unpuser, user->pw_gid)) {
 		logg("^initgroups() failed.\n");
 		opt_free(opt);
+		freecfg(copt);
 		return 61;
 	    }
 #endif
@@ -334,6 +327,7 @@ int main(int argc, char **argv)
 	    if(setgroups(1, &user->pw_gid)) {
 		logg("^setgroups() failed.\n");
 		opt_free(opt);
+		freecfg(copt);
 		return 61;
 	    }
 #endif
@@ -342,12 +336,14 @@ int main(int argc, char **argv)
 	if(setgid(user->pw_gid)) {
 	    logg("^setgid(%d) failed.\n", (int) user->pw_gid);
 	    opt_free(opt);
+	    freecfg(copt);
 	    return 61;
 	}
 
 	if(setuid(user->pw_uid)) {
 	    logg("^setuid(%d) failed.\n", (int) user->pw_uid);
 	    opt_free(opt);
+	    freecfg(copt);
 	    return 61;
 	}
     }
@@ -377,6 +373,7 @@ int main(int argc, char **argv)
 	if(logg("#--------------------------------------\n")) {
 	    mprintf("!Problem with internal logger (--log=%s).\n", logg_file);
 	    opt_free(opt);
+	    freecfg(copt);
 	    return 62;
 	}
     } else if((cpt = cfgopt(copt, "UpdateLogFile"))->enabled) {
@@ -384,6 +381,7 @@ int main(int argc, char **argv)
 	if(logg("#--------------------------------------\n")) {
 	    mprintf("!Problem with internal logger (UpdateLogFile = %s).\n", logg_file);
 	    opt_free(opt);
+	    freecfg(copt);
 	    return 62;
 	}
     } else
@@ -397,6 +395,7 @@ int main(int argc, char **argv)
 	    if((fac = logg_facility(cpt->strarg)) == -1) {
 		mprintf("!LogFacility: %s: No such facility.\n", cpt->strarg);
 		opt_free(opt);
+		freecfg(copt);
 		return 62;
 	    }
 	}
@@ -415,6 +414,7 @@ int main(int argc, char **argv)
     if(chdir(newdir)) {
 	logg("Can't change dir to %s\n", newdir);
 	opt_free(opt);
+	freecfg(copt);
 	return 50;
     } else
 	logg("*Current working dir is %s\n", newdir);
@@ -423,10 +423,14 @@ int main(int argc, char **argv)
     if(opt_check(opt, "list-mirrors")) {
 	if(mirman_read("mirrors.dat", &mdat, 1) == -1) {
 	    printf("Can't read mirrors.dat\n");
+	    opt_free(opt);
+	    freecfg(copt);
 	    return 55;
 	}
 	mirman_list(&mdat);
 	mirman_free(&mdat);
+	opt_free(opt);
+	freecfg(copt);
 	return 0;
     }
 
@@ -436,6 +440,8 @@ int main(int argc, char **argv)
 
 	if(WSAStartup(MAKEWORD(2,2), &wsaData) != NO_ERROR) {
 	    logg("!Error at WSAStartup(): %d\n", WSAGetLastError());
+	    opt_free(opt);
+	    freecfg(copt);
 	    return 1;
 	}
     }
@@ -458,6 +464,7 @@ int main(int argc, char **argv)
 	if(checks <= 0) {
 	    logg("^Number of checks must be a positive integer.\n");
 	    opt_free(opt);
+	    freecfg(copt);
 	    return 41;
 	}
 
@@ -465,6 +472,7 @@ int main(int argc, char **argv)
 	    if(checks > 50) {
 		logg("^Number of checks must be between 1 and 50.\n");
 		opt_free(opt);
+		freecfg(copt);
 		return 41;
 	    }
 	}
@@ -568,6 +576,7 @@ int main(int argc, char **argv)
     }
 
     opt_free(opt);
+    freecfg(copt);
 
 #ifdef C_WINDOWS
     WSACleanup();
