@@ -69,6 +69,8 @@ static	char	const	rcsid[] = "$Id: blob.c,v 1.64 2007/02/12 22:25:14 njh Exp $";
 				 * large sized files
 				 */
 
+static	const	char	*blobGetFilename(const blob *b);
+
 blob *
 blobCreate(void)
 {
@@ -135,10 +137,10 @@ blobSetFilename(blob *b, const char *dir, const char *filename)
 	b->name = cli_strdup(filename);
 
 	if(b->name)
-		cli_sanitise_filename(b->name);
+		sanitiseName(b->name);
 }
 
-const char *
+static const char *
 blobGetFilename(const blob *b)
 {
 	assert(b != NULL);
@@ -240,7 +242,7 @@ blobGetData(const blob *b)
 
 	if(b->len == 0)
 		return NULL;
-	return(b->data);
+	return b->data;
 }
 
 size_t
@@ -249,7 +251,7 @@ blobGetDataSize(const blob *b)
 	assert(b != NULL);
 	assert(b->magic == BLOBCLASS);
 
-	return(b->len);
+	return b->len;
 }
 
 void
@@ -559,3 +561,32 @@ fileblobContainsVirus(const fileblob *fb)
 {
 	return fb->isInfected ? TRUE : FALSE;
 }
+
+/*
+ * Different operating systems allow different characters in their filenames
+ * FIXME: What does QNX want? There is no #ifdef C_QNX, but if there were
+ * it may be best to treat it like MSDOS
+ */
+void
+sanitiseName(char *name)
+{
+	while(*name) {
+#ifdef	C_DARWIN
+		*name &= '\177';
+#endif
+		/* Also check for tab - "Heinz Martin" <Martin@hemag.ch> */
+#if	defined(MSDOS) || defined(C_OS2)
+		/*
+		 * Don't take it from this that ClamAV supports DOS, it doesn't
+		 * I don't know if spaces are legal in OS/2.
+		 */
+		if(strchr("%/*?<>|\\\"+=,;:\t ~", *name))
+#elif	defined(C_CYGWIN) || defined(C_WINDOWS)
+		if(strchr("%/*?<>|\\\"+=,;:\t~", *name))
+#else
+		if(*name == '/')
+#endif
+			*name = '_';
+		name++;
+	}
+}
