@@ -831,7 +831,7 @@ static int chm_decompress_stream(int fd, const char *dirname, itsf_header_t *its
 	
 	snprintf(filename, 1024, "%s/clamav-unchm.bin", dirname);
 	tmpfd = open(filename, O_WRONLY|O_CREAT|O_TRUNC|O_BINARY, S_IRWXU);
-	if (!tmpfd) {
+	if (tmpfd<0) {
 		cli_dbgmsg("open failed for %s\n", filename);
 		return FALSE;
 	}
@@ -943,9 +943,13 @@ static int chm_decompress_stream(int fd, const char *dirname, itsf_header_t *its
 		count++;
 	}
 	close(tmpfd);
+	tmpfd=-1;
 	retval = TRUE;
 	
 abort:
+	if (tmpfd>=0) {
+		close(tmpfd);
+	}
 	if (lzx_content) {
 		free(lzx_content);
 	}
