@@ -39,6 +39,12 @@ struct dconf_module {
     uint8_t	state;	    /* default state (on/off) */
 };
 
+#ifdef CL_EXPERIMENTAL
+#define DCONF_ENABLE_EXPERIMENTAL 1
+#else
+#define DCONF_ENABLE_EXPERIMENTAL 0
+#endif
+
 static struct dconf_module modules[] = {
 
     { "PE",	    "PARITE",	    PE_CONF_PARITE,	    1 },
@@ -49,16 +55,17 @@ static struct dconf_module modules[] = {
     { "PE",	    "UPX",	    PE_CONF_UPX,	    1 },
     { "PE",	    "FSG",	    PE_CONF_FSG,	    1 },
 
-    { "PE",	    "SUE",	    PE_CONF_SUE,	    1 }, /* exp */
+    { "PE",	    "SUE",	    PE_CONF_SUE,	    1 },
 
     { "PE",	    "PETITE",	    PE_CONF_PETITE,	    1 },
     { "PE",	    "PESPIN",	    PE_CONF_PESPIN,	    1 },
     { "PE",	    "YC",	    PE_CONF_YC,		    1 },
     { "PE",	    "WWPACK",	    PE_CONF_WWPACK,	    1 },
 
-    { "PE",	    "NSPACK",	    PE_CONF_NSPACK,	    1 }, /* exp */
-    { "PE",	    "MEW",	    PE_CONF_MEW,	    1 }, /* exp */
-    { "PE",	    "UPACK",	    PE_CONF_UPACK,	    1 }, /* exp */
+    { "PE",	    "NSPACK",	    PE_CONF_NSPACK,	    1 },
+    { "PE",	    "MEW",	    PE_CONF_MEW,	    1 },
+    { "PE",	    "UPACK",	    PE_CONF_UPACK,	    1 },
+    { "PE",	    "ASPACK",	    PE_CONF_ASPACK,	    1 },
 
     { "ELF",	    NULL,	    0x1,		    1 },
 
@@ -73,6 +80,7 @@ static struct dconf_module modules[] = {
     { "ARCHIVE",    "TAR",	    ARCH_CONF_TAR,	    1 },
     { "ARCHIVE",    "BINHEX",	    ARCH_CONF_BINHEX,	    1 },
     { "ARCHIVE",    "SIS",	    ARCH_CONF_SIS,	    1 },
+    { "ARCHIVE",    "NSIS",	    ARCH_CONF_NSIS,	    1 },
 
     { "DOCUMENT",   "HTML",	    DOC_CONF_HTML,	    1 },
     { "DOCUMENT",   "RTF",	    DOC_CONF_RTF,	    1 },
@@ -80,6 +88,7 @@ static struct dconf_module modules[] = {
 
     { "MAIL",	    "MBOX",	    MAIL_CONF_MBOX,	    1 },
     { "MAIL",	    "TNEF",	    MAIL_CONF_TNEF,	    1 },
+    { "MAIL",	    "PST",	    MAIL_CONF_PST,	    1 },
 
     { "OTHER",	    "UUENCODED",    OTHER_CONF_UUENC,	    1 },
     { "OTHER",	    "SCRENC",	    OTHER_CONF_SCRENC,	    1 },
@@ -87,6 +96,9 @@ static struct dconf_module modules[] = {
     { "OTHER",	    "JPEG",	    OTHER_CONF_JPEG,	    1 },
     { "OTHER",	    "CRYPTFF",	    OTHER_CONF_CRYPTFF,	    1 },
 
+    { "PHISHING",   "ENGINE",       PHISHING_CONF_ENGINE,   1 },
+    { "PHISHING",   "ENTCONV",      PHISHING_CONF_ENTCONV,  DCONF_ENABLE_EXPERIMENTAL }, /* exp */
+
     { NULL,	    NULL,	    0,			    0 }
 };
 
@@ -124,6 +136,9 @@ struct cli_dconf *cli_dconf_init(void)
 	} else if(!strcmp(modules[i].mname, "OTHER")) {
 	    if(modules[i].state)
 		dconf->other |= modules[i].bflag;
+	} else if(!strcmp(modules[i].mname, "PHISHING")) {
+	    if(modules[i].state)
+		dconf->phishing |= modules[i].bflag;
 	}
     }
 
@@ -132,7 +147,7 @@ struct cli_dconf *cli_dconf_init(void)
 
 void cli_dconf_print(struct cli_dconf *dconf)
 {
-	uint8_t pe = 0, elf = 0, arch = 0, doc = 0, mail = 0, other = 0;
+	uint8_t pe = 0, elf = 0, arch = 0, doc = 0, mail = 0, other = 0, phishing=0;
 	unsigned int i;
 
 
@@ -195,6 +210,15 @@ void cli_dconf_print(struct cli_dconf *dconf)
 		cli_dbgmsg("   * Submodule %10s:\t%s\n", modules[i].sname, (dconf->other & modules[i].bflag) ? "On" : "** Off **");
 	    else
 		continue;
+	} else if(!strcmp(modules[i].mname, "PHISHING")) {
+	    if(!phishing) {
+		cli_dbgmsg("Module PHISHING %s\n", dconf->phishing ? "On" : "Off");
+		phishing = 1;
+	    }
+	    if(dconf->phishing)
+		cli_dbgmsg("   * Submodule %10s:\t%s\n", modules[i].sname, (dconf->phishing & modules[i].bflag) ? "On" : "** Off **");
+	    else
+		continue;
 	}
     }
 }
@@ -308,6 +332,15 @@ int cli_dconf_load(FILE *fd, struct cl_engine **engine, unsigned int options)
 		break;
 	    }
 	}
+
+	if(!strncmp(buffer, "PHISHING:", 9) && chkflevel(buffer, 2)) {
+	    if(sscanf(buffer + 9, "0x%x", &val) == 1) {
+		dconf->phishing = val;
+	    } else {
+		ret = CL_EMALFDB;
+		break;
+	    }
+	}
     }
 
     if(ret) {
