@@ -31,6 +31,7 @@ struct cli_dconf {
     uint32_t doc;
     uint32_t mail;
     uint32_t other;
+    uint32_t phishing;
 };
 
 /* PE flags */
@@ -49,6 +50,7 @@ struct cli_dconf {
 #define PE_CONF_NSPACK	    0x1000
 #define PE_CONF_MEW	    0x2000
 #define PE_CONF_UPACK	    0x4000
+#define PE_CONF_ASPACK	    0x8000
 
 /* Archive flags */
 #define ARCH_CONF_RAR	    0x1
@@ -62,6 +64,7 @@ struct cli_dconf {
 #define ARCH_CONF_TAR	    0x100
 #define ARCH_CONF_BINHEX    0x200
 #define ARCH_CONF_SIS	    0x400
+#define ARCH_CONF_NSIS	    0x800
 
 /* Document flags */
 #define DOC_CONF_HTML	    0x1
@@ -71,6 +74,7 @@ struct cli_dconf {
 /* Mail flags */
 #define MAIL_CONF_MBOX	    0x1
 #define MAIL_CONF_TNEF	    0x2
+#define MAIL_CONF_PST	    0x4
 
 /* Other flags */
 #define OTHER_CONF_UUENC    0x1
@@ -79,6 +83,9 @@ struct cli_dconf {
 #define OTHER_CONF_JPEG	    0x8
 #define OTHER_CONF_CRYPTFF  0x10
 
+/* Phishing flags */
+#define PHISHING_CONF_ENGINE   0x1
+#define PHISHING_CONF_ENTCONV  0x2
 
 struct cli_dconf *cli_dconf_init(void);
 void cli_dconf_print(struct cli_dconf *dconf);
