@@ -4,9 +4,8 @@
  *  Copyright (C) 2006 Trk Edvin <edwin@clamav.net>
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as 
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,13 +20,11 @@
  */
 #include "clamav-config.h"
 
-#ifdef CL_EXPERIMENTAL
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
-#include <dirent.h>
 #include <errno.h>
 
 
@@ -64,8 +61,6 @@ unsigned char* entity_norm(const struct entity_conv* conv,const unsigned char* e
 			return (unsigned char*)cli_strdup("&lt;");
 		else if(val == '>')/* see above */
 			return (unsigned char*)cli_strdup("&gt;");
-		else if(val == '&')/* see above */
-			return (unsigned char*)cli_strdup("&amp;");
 		else if(val<127) {
 			unsigned char *e_out = cli_malloc(2);
 
@@ -101,7 +96,7 @@ unsigned char* entity_norm(const struct entity_conv* conv,const unsigned char* e
 int init_entity_converter(struct entity_conv* conv,const unsigned char* encoding,size_t buffer_size)
 {
 	if(buffer_size < MIN_BUFFER_SIZE) {
-		cli_warnmsg("Entity converter: Supplied buffer size:%ld, smaller than minimum required: %ld\n",buffer_size,MIN_BUFFER_SIZE);
+		cli_warnmsg("Entity converter: Supplied buffer size:%lu, smaller than minimum required: %d\n",(unsigned long)buffer_size,MIN_BUFFER_SIZE);
 		return CL_ENULLARG;
 	}
 	if(conv) {
@@ -519,7 +514,7 @@ void process_encoding_set(struct entity_conv* conv,const unsigned char* encoding
 	enum encodings tmp;
 	size_t new_size,old_size;
 
-	cli_dbgmsg("Setting encoding for %x  to %s, priority: %d\n",conv, encoding, prio);
+	cli_dbgmsg("Setting encoding for %p  to %s, priority: %d\n",(void*)conv, encoding, prio);
 	if(encoding == OTHER)
 		return;
 	if(conv->priority == CONTENT_TYPE)
@@ -532,14 +527,15 @@ void process_encoding_set(struct entity_conv* conv,const unsigned char* encoding
 	old_size = encoding_bytes(conv->encoding,&tmp);
 	new_size = encoding_bytes(tmp_encoding,&tmp);
 	if(old_size != new_size)  {
-		cli_dbgmsg("process_encoding_set: refusing to override encoding - new encoding size differs: %s(%ld) != %s(%ld)\n",conv->encoding,old_size,tmp_encoding,new_size);
+		/* on x86 gcc wants %u for size_t, on x86_64 it wants %lu for size_t. So just cast to unsigned long to make warnings go away. */
+		cli_dbgmsg("process_encoding_set: refusing to override encoding - new encoding size differs: %s(%lu) != %s(%lu)\n",conv->encoding,(unsigned long)old_size,tmp_encoding,(unsigned long)new_size);
 		free(tmp_encoding);
 		return;
 	}
 	}
 	free(conv->encoding);
 	conv->encoding = tmp_encoding;
-	cli_dbgmsg("New encoding for %x:%s\n",conv,conv->encoding);
+	cli_dbgmsg("New encoding for %p:%s\n",(void*)conv,conv->encoding);
 	/* reset stream */
 }
 
@@ -570,7 +566,7 @@ int entity_norm_done(struct entity_conv* conv)
 	return encoding_norm_done(conv);
 }
 
-static size_t read_raw(FILE *stream, m_area_t *m_area, unsigned int max_len, unsigned char* outbuff)
+static size_t read_raw(FILE *stream, m_area_t *m_area, int max_len, unsigned char* outbuff)
 {
 
 	/* Try and use the memory buffer first */
@@ -655,14 +651,14 @@ static void iconv_cache_init(struct iconv_cache* cache)
 /*	cache->tab = NULL;
 	cache->len = 0;
 	cache->used = 0; - already done by memset*/
-	cli_dbgmsg("Initializing iconv pool:%p\n",cache);
+	cli_dbgmsg("Initializing iconv pool:%p\n",(void*)cache);
 	hashtab_init(&cache->hashtab, 32);
 }
 
 static void iconv_cache_destroy(struct iconv_cache* cache)
 {
 	size_t i;
-	cli_dbgmsg("Destroying iconv pool:%p\n",cache);
+	cli_dbgmsg("Destroying iconv pool:%p\n",(void*)cache);
 	for(i=0;i < cache->last;i++) {
 		cli_dbgmsg("closing iconv:%p\n",cache->tab[i]);
 		iconv_close(cache->tab[i]);
@@ -792,7 +788,7 @@ static iconv_t iconv_open_cached(const unsigned char* fromcode)
 	idx = cache->last++;
 	if(idx >= cache->len) {
 		cache->len += 16;
-		cache->tab = cli_realloc(cache->tab, cache->len*sizeof(cache->tab[0]));
+		cache->tab = cli_realloc2(cache->tab, cache->len*sizeof(cache->tab[0]));
 		if(!cache->tab) {
 			cli_dbgmsg("!Out of mem in iconv-pool\n");
 			errno = ENOMEM;
@@ -898,7 +894,7 @@ unsigned char* encoding_norm_readline(struct entity_conv* conv, FILE* stream_in,
 #endif
 
 		if(rc==(size_t)-1 && errno != E2BIG) {
-				cli_dbgmsg("iconv error:%s, silently resuming (%ld,%ld,%ld,%ld)\n",strerror(errno),out-conv->out_area.buffer,tmpbuff-conv->tmp_area.buffer,inleft,outleft);
+				cli_dbgmsg("iconv error:%s, silently resuming (%ld,%ld,%lu,%lu)\n",strerror(errno),(long)(out-conv->out_area.buffer),(long)(tmpbuff-conv->tmp_area.buffer),(unsigned long)inleft,(unsigned long)outleft);
 				/* output raw byte, and resume at next byte */
 				*out++ = 0;
 				*out++ = *tmpbuff++;
@@ -945,7 +941,7 @@ unsigned char* encoding_norm_readline(struct entity_conv* conv, FILE* stream_in,
 					cli_dbgmsg("Skipping null character in html stream\n");
 			}
 			}
-			else if((u16 < 0x80 && u16 >= 0x20) || (u16 <= 0xff && isspace(u16))) {
+			else if(u16 < 0x80) {
 				if(norm >= norm_end)
 					break;
 				if((unsigned char)u16 ==0)
@@ -983,4 +979,3 @@ unsigned char* encoding_norm_readline(struct entity_conv* conv, FILE* stream_in,
 	}
 }
 
-#endif
