@@ -3,9 +3,8 @@
  *  With enhancements from Thomas Lamy <Thomas.Lamy@in-online.net>
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,7 +24,7 @@
 
 #define MAGIC_BUFFER_SIZE 256
 #define CL_TYPENO 500
-#define SFX_MAX_TESTS 10
+#define MAX_EMBEDDED_OBJ 10
 
 typedef enum {
     CL_TYPE_UNKNOWN_TEXT = CL_TYPENO,
@@ -61,7 +60,8 @@ typedef enum {
     CL_TYPE_SFX, /* foo SFX marker */
     CL_TYPE_ZIPSFX, /* on the fly */
     CL_TYPE_RARSFX, /* on the fly */
-    CL_TYPE_CABSFX
+    CL_TYPE_CABSFX,
+    CL_TYPE_NULSFT /* on the fly */
 
 } cli_file_t;
 
