@@ -1,10 +1,10 @@
 /*
- *  Copyright (C) 2006 Tomasz Kojm <tkojm@clamav.net>
+ *  Copyright (C) 2006 Sensory Networks, Inc.
+ *	      Written by Tomasz Kojm, dlopen() support by Peter Duthie
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
