@@ -1,10 +1,9 @@
 /*
- *  Copyright (C) 2002 - 2006 Tomasz Kojm <tkojm@clamav.net>
+ *  Copyright (C) 2002 - 2007 Tomasz Kojm <tkojm@clamav.net>
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -41,6 +40,7 @@
 #include "execs.h"
 #include "special.h"
 #include "str.h"
+#include "cltypes.h"
 
 #ifdef HAVE_NCORE
 #include "matcher-ncore.h"
@@ -50,9 +50,10 @@ static cli_file_t targettab[CL_TARGET_TABLE_SIZE] = { 0, CL_TYPE_MSEXE, CL_TYPE_
 
 extern short cli_debug_flag;
 
-int cli_scanbuff(const unsigned char *buffer, unsigned int length, const char **virname, const struct cl_engine *engine, cli_file_t ftype)
+int cli_scanbuff(const unsigned char *buffer, uint32_t length, const char **virname, const struct cl_engine *engine, cli_file_t ftype)
 {
-	int ret = CL_CLEAN, i;
+	int ret = CL_CLEAN;
+	unsigned int i;
 	struct cli_ac_data mdata;
 	struct cli_matcher *groot, *troot = NULL;
 
@@ -121,10 +122,11 @@ struct cli_md5_node *cli_vermd5(const unsigned char *md5, const struct cl_engine
     return NULL;
 }
 
-off_t cli_caloff(const char *offstr, struct cli_target_info *info, int fd, cli_file_t ftype, int *ret)
+off_t cli_caloff(const char *offstr, struct cli_target_info *info, int fd, cli_file_t ftype, int *ret, unsigned int *maxshift)
 {
 	int (*einfo)(int, struct cli_exe_info *) = NULL;
 	unsigned int n, val;
+	const char *pt;
 	off_t pos, offset;
 
 
@@ -162,6 +164,9 @@ off_t cli_caloff(const char *offstr, struct cli_target_info *info, int fd, cli_f
 	}
     }
 
+    if((pt = strchr(offstr, ',')))
+	*maxshift = atoi(++pt);
+
     if(isdigit(offstr[0])) {
 	return atoi(offstr);
 
@@ -256,17 +261,23 @@ int cli_validatesig(cli_file_t ftype, const char *offstr, off_t fileoff, struct
 {
 	off_t offset;
 	int ret;
+	unsigned int maxshift = 0;
 
 
     if(offstr && desc != -1) {
-	offset = cli_caloff(offstr, info, desc, ftype, &ret);
+	offset = cli_caloff(offstr, info, desc, ftype, &ret, &maxshift);
 
 	if(ret == -1) {
 	    cli_dbgmsg("cli_validatesig: Can't calculate offset for signature %s\n", virname);
 	    return 0;
 	}
 
-	if(fileoff != offset) {
+	if(maxshift) {
+	    if((fileoff < offset) || (fileoff > offset + (off_t) maxshift)) {
+		cli_dbgmsg("Signature offset: %lu, expected: [%lu..%lu] (%s)\n", fileoff, offset, offset + maxshift, virname);
+		return 0;
+	    }
+	} else if(fileoff != offset) {
 	    cli_dbgmsg("Signature offset: %lu, expected: %lu (%s)\n", fileoff, offset, virname);
 	    return 0;
 	}
@@ -275,12 +286,11 @@ int cli_validatesig(cli_file_t ftype, const char *offstr, off_t fileoff, struct
     return 1;
 }
 
-int cli_scandesc(int desc, cli_ctx *ctx, unsigned short otfrec, cli_file_t ftype, unsigned short ftonly, struct cli_matched_type **ftoffset)
+int cli_scandesc(int desc, cli_ctx *ctx, uint8_t otfrec, cli_file_t ftype, uint8_t ftonly, struct cli_matched_type **ftoffset)
 {
  	unsigned char *buffer, *buff, *endbl, *upt;
 	int ret = CL_CLEAN, type = CL_CLEAN, i, bytes;
-	unsigned int buffersize, length, maxpatlen, shift = 0;
-	unsigned long int offset = 0;
+	uint32_t buffersize, length, maxpatlen, shift = 0, offset = 0;
 	struct cli_ac_data gdata, tdata;
 	cli_md5_ctx md5ctx;
 	unsigned char digest[16];
