@@ -79,7 +79,7 @@ static const unsigned char mszip_bitlen_order[19] = {
 };
 
 /* ANDing with mszip_bit_mask[n] masks the lower n bits */
-static const unsigned short mszip_bit_mask[17] = {
+static const unsigned short mszip_bit_mask_tab[17] = {
  0x0000, 0x0001, 0x0003, 0x0007, 0x000f, 0x001f, 0x003f, 0x007f, 0x00ff,
  0x01ff, 0x03ff, 0x07ff, 0x0fff, 0x1fff, 0x3fff, 0x7fff, 0xffff
 };
@@ -110,7 +110,7 @@ static const unsigned short mszip_bit_mask[17] = {
 } while (0)
 
 #define MSZIP_PEEK_BITS(nbits)   (bit_buffer & ((1<<(nbits))-1))
-#define MSZIP_PEEK_BITS_T(nbits) (bit_buffer & mszip_bit_mask[(nbits)])
+#define MSZIP_PEEK_BITS_T(nbits) (bit_buffer & mszip_bit_mask_tab[(nbits)])
 
 #define MSZIP_REMOVE_BITS(nbits) ((bit_buffer >>= (nbits)), (bits_left -= (nbits)))
 
@@ -271,8 +271,13 @@ static int mszip_make_decode_table(unsigned int nsyms, unsigned int nbits,
         cli_dbgmsg("zip_inflate: out of bits in huffman decode\n");	\
         return INF_ERR_HUFFSYM;                                         \
       }                                                                 \
+      sym = (sym << 1) | ((bit_buffer >> i) & 1);			\
+      if(sym >= MSZIP_##tbl##_TABLESIZE) {				\
+	cli_dbgmsg("zip_inflate: index out of table\n");		\
+        return INF_ERR_HUFFSYM;                                         \
+      }									\
       /* double node index and add 0 (left branch) or 1 (right) */	\
-      sym = zip->tbl##_table[(sym << 1) | ((bit_buffer >> i) & 1)];	\
+      sym = zip->tbl##_table[sym];					\
       /* while we are still in node indicies, not decoded symbols */    \
     } while (sym >= MSZIP_##tbl##_MAXSYMBOLS);                          \
   }                                                                     \
@@ -798,7 +803,11 @@ static int lzx_read_input(struct lzx_stream *lzx) {
       /* double node index and add 0 (left branch) or 1 (right) */      \
       sym <<= 1; sym |= (bit_buffer & i) ? 1 : 0;                       \
       /* hop to next node index / decoded symbol */                     \
-      sym = lzx->tbl##_table[sym];                                      \
+      if(sym >= (1 << LZX_##tbl##_TABLEBITS) + (LZX_##tbl##_MAXSYMBOLS * 2)) { \
+	cli_dbgmsg("lzx: index out of table\n");			\
+	return lzx->error = CL_EFORMAT;					\
+      }									\
+      sym = lzx->tbl##_table[sym];                                    \
       /* while we are still in node indicies, not decoded symbols */    \
     } while (sym >= LZX_##tbl##_MAXSYMBOLS);                            \
   }                                                                     \
