@@ -1,12 +1,11 @@
 /*
  *  Phishing module: domain list implementation.
  *
- *  Copyright (C) 2006 Trk Edvin <edwintorok@gmail.com>
+ *  Copyright (C) 2006-2007 Trk Edvin <edwin@clamav.net>
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as 
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,10 +19,10 @@
  *
  */
 
-#ifdef CL_EXPERIMENTAL
 
 #ifndef _PHISH_DOMAINCHECK_DB_H
 #define _PHISH_DOMAINCHECK_DB_H
+#include "clamav.h"
 
 int init_domainlist(struct cl_engine* engine);
 void domainlist_done(struct cl_engine* engine);
@@ -33,4 +32,3 @@ int domainlist_match(const struct cl_engine* engine,const char* real_url,const c
 
 #endif
 
-#endif
