@@ -141,12 +141,11 @@ For the Whitelist(.wdb)/Domainlist(.pdb) format see regex_list.c (search for Fla
 /* Constant strings and tables */ 
 static char empty_string[]="";
 
-#define ANY_CLOAK "(((0[xX])?[a-fA-F0-9])+\\.?)+"
-#define CLOAK_REGEX_HEXURL "("ANY_CLOAK")?0[xX][a-fA-F0-9]+\\.?"ANY_CLOAK
-#define OCTAL_CLOAK "("ANY_CLOAK")?000[0-9]+\\.?"ANY_CLOAK
-#define DWORD_CLOAK "[0-9]{8,}"
 
-static const char cloaked_host_regex[] = "^(("CLOAK_REGEX_HEXURL")|("OCTAL_CLOAK")|("DWORD_CLOAK"))$";
+#define ANY_CLOAK "(0[xX][0-9a-fA-F]+|[0-9]+)"
+#define CLOAKED_URL "^"ANY_CLOAK"(\\."ANY_CLOAK"){0,3}$"
+
+static const char cloaked_host_regex[] = CLOAKED_URL;
 static const char tld_regex[] = "^"iana_tld"$";
 static const char cctld_regex[] = "^"iana_cctld"$";
 static const char dotnet[] = ".net";
@@ -353,7 +352,7 @@ static void free_if_needed(struct url_check* url)
 static int build_regex(regex_t* preg,const char* regex,int nosub)
 {
 	int rc;
-	cli_dbgmsg("Phishcheck: Compiling regex:%s\n",regex);
+	cli_dbgmsg("Phishcheck: Compiling regex: %s\n",regex);
 	rc = regcomp(preg,regex,REG_EXTENDED|REG_ICASE|(nosub ? REG_NOSUB :0));
 	if(rc) {
 	
@@ -402,7 +401,7 @@ static int get_host(const struct phishcheck* s,struct string* dest,const char* U
 		else {
 			start=URL;/*URL without protocol*/
 			if(isReal)
-				cli_dbgmsg("Phishcheck: Real URL without protocol:%s\n",URL);
+				cli_dbgmsg("Phishcheck: Real URL without protocol: %s\n",URL);
 			else ismailto=2;/*no-protocol, might be mailto, @ is no problem*/
 		}
 	}
@@ -626,7 +625,7 @@ str_strip(char **begin, const char **end, const char *what, size_t what_len)
 /* replace every occurrence of @c in @str with @r*/
 static void str_replace(char* str,const char* end,char c,char r)
 {
-	for(;str<end;str++) {
+	for(;str<=end;str++) {
 		if(*str==c)
 			*str=r;
 	}
@@ -723,6 +722,10 @@ cleanupURL(struct string *URL, int isReal)
 		int rc;
 
 		str_replace(begin,end,'\\','/');
+		/* some broken MUAs put > in the href, and then
+		 * we get a false positive, so remove them */
+		str_replace(begin,end,'<','/');
+		str_replace(begin,end,'>','/');
 		str_strip(&begin,&end,"\"",1);
 		str_strip(&begin,&end,lt,lt_len);
 		str_strip(&begin,&end,gt,gt_len);
@@ -802,7 +805,7 @@ int phishingScan(message* m,const char* dir,cli_ctx* ctx,tag_arguments_t* hrefs)
 			if(pchk->is_disabled)
 				return CL_CLEAN;
 			free_if_needed(&urls);
-			cli_dbgmsg("Phishcheck: Phishing scan result:%s\n",phishing_ret_toString(rc));
+			cli_dbgmsg("Phishcheck: Phishing scan result: %s\n",phishing_ret_toString(rc));
 			switch(rc)/*TODO: support flags from ctx->options,*/
 				{
 					case CL_PHISH_CLEAN:
