@@ -1,12 +1,11 @@
 /*
  *  Match a string against a list of patterns/regexes.
  *
- *  Copyright (C) 2006 Trk Edvin <edwintorok@gmail.com>
+ *  Copyright (C) 2006 Trk Edvin <edwin@clamav.net>
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as 
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,13 +19,10 @@
  *
  */
 
-#ifdef CL_EXPERIMENTAL
 
 #ifndef _REGEX_LIST_H
 #define _REGEX_LIST_H
 
-
-
 #ifdef NDEBUG
 #define massert(x) (void)(0)
 #else
@@ -46,6 +42,7 @@ struct node_stack {
 struct regex_matcher {
 	struct cli_matcher* root_hosts;
 	struct tree_node* root_regex;
+	struct tree_node* root_regex_hostonly; 
 	size_t root_hosts_cnt;
 	int list_inited;
 	int list_loaded;
@@ -61,7 +58,5 @@ void regex_list_cleanup(struct regex_matcher* matcher);
 void regex_list_done(struct regex_matcher* matcher);
 int is_regex_ok(struct regex_matcher* matcher);
 
-void setup_matcher_engine(void);/* global, non thread-safe */
 #endif
 
-#endif
