@@ -1,10 +1,9 @@
 /*
- *  Copyright (C) 2002 - 2005 Tomasz Kojm <tkojm@clamav.net>
+ *  Copyright (C) 2002 - 2007 Tomasz Kojm <tkojm@clamav.net>
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -102,6 +101,7 @@ extern short cli_leavetemps_flag;
 
 #define MAX_MAIL_RECURSION  15
 
+int cli_scannulsft(int desc, cli_ctx *ctx, off_t offset); /* FIXME */
 static int cli_scanfile(const char *filename, cli_ctx *ctx);
 
 static int cli_unrar_scanmetadata(int desc, rar_metadata_t *metadata, cli_ctx *ctx, unsigned int files, uint32_t* sfx_check)
@@ -117,10 +117,10 @@ static int cli_unrar_scanmetadata(int desc, rar_metadata_t *metadata, cli_ctx *c
 	    *sfx_check = metadata->crc;
     }
 
-    cli_dbgmsg("RAR: %s, crc32: 0x%x, encrypted: %d, compressed: %u, normal: %u, method: %d, ratio: %d (max: %d)\n",
-	metadata->filename, metadata->crc, metadata->encrypted, metadata->pack_size,
-	metadata->unpack_size, metadata->method,
-	metadata->pack_size ? ((unsigned int) metadata->unpack_size / (unsigned int) metadata->pack_size) : 0, ctx->limits ? ctx->limits->maxratio : 0);
+    cli_dbgmsg("RAR: %s, crc32: 0x%x, encrypted: %u, compressed: %u, normal: %u, method: %u, ratio: %u (max: %u)\n",
+	metadata->filename, metadata->crc, metadata->encrypted, (unsigned int) metadata->pack_size,
+	(unsigned int) metadata->unpack_size, metadata->method,
+	metadata->pack_size ? (unsigned int) (metadata->unpack_size / metadata->pack_size) : 0, ctx->limits ? ctx->limits->maxratio : 0);
 
     /* Scan metadata */
     mdata = ctx->engine->rar_mlist;
@@ -186,7 +186,7 @@ static int cli_unrar_checklimits(const cli_ctx *ctx, const rar_metadata_t *metad
     if(ctx->limits) {
 	if(ctx->limits->maxratio && metadata->unpack_size && metadata->pack_size) {
 	    if(metadata->unpack_size / metadata->pack_size >= ctx->limits->maxratio) {
-		cli_dbgmsg("RAR: Max ratio reached (normal: %Lu, compressed: %Lu, max: %u)\n", metadata->unpack_size, metadata->pack_size, ctx->limits->maxratio);
+		cli_dbgmsg("RAR: Max ratio reached (%u, max: %u)\n", (unsigned int) (metadata->unpack_size / metadata->pack_size), ctx->limits->maxratio);
 		if(BLOCKMAX) {
 		    *ctx->virname = "Oversized.RAR";
 		    return CL_VIRUS;
@@ -196,7 +196,7 @@ static int cli_unrar_checklimits(const cli_ctx *ctx, const rar_metadata_t *metad
 	}
 
 	if(ctx->limits->maxfilesize && (metadata->unpack_size > ctx->limits->maxfilesize)) {
-	    cli_dbgmsg("RAR: %s: Size exceeded (%Lu, max: %lu)\n", metadata->filename, metadata->unpack_size, ctx->limits->maxfilesize);
+	    cli_dbgmsg("RAR: %s: Size exceeded (%lu, max: %lu)\n", metadata->filename, (unsigned long int) metadata->unpack_size, ctx->limits->maxfilesize);
 	    if(BLOCKMAX) {
 		*ctx->virname = "RAR.ExceededFileSize";
 		return CL_VIRUS;
@@ -366,7 +366,7 @@ static int cli_scanzip(int desc, cli_ctx *ctx, off_t sfx_offset, uint32_t *sfx_c
 	 */
 	encrypted = ((zdirent.d_flags & 0x2041) != 0);
 
-	cli_dbgmsg("Zip: %s, crc32: 0x%x, offset: %d, encrypted: %d, compressed: %u, normal: %u, method: %d, ratio: %d (max: %d)\n", zdirent.d_name, zdirent.d_crc32, zdirent.d_off, encrypted, zdirent.d_csize, zdirent.st_size, zdirent.d_compr, zdirent.d_csize ? (zdirent.st_size / zdirent.d_csize) : 0, ctx->limits ? ctx->limits->maxratio : 0);
+	cli_dbgmsg("Zip: %s, crc32: 0x%x, offset: %u, encrypted: %u, compressed: %u, normal: %u, method: %u, ratio: %u (max: %u)\n", zdirent.d_name, zdirent.d_crc32, zdirent.d_off, encrypted, zdirent.d_csize, zdirent.st_size, zdirent.d_compr, zdirent.d_csize ? (zdirent.st_size / zdirent.d_csize) : 0, ctx->limits ? ctx->limits->maxratio : 0);
 
 	if(!zdirent.st_size) {
 	    if(zdirent.d_crc32) {
@@ -457,7 +457,7 @@ static int cli_scanzip(int desc, cli_ctx *ctx, off_t sfx_offset, uint32_t *sfx_c
 
 	if(ctx->limits) {
 	    if(ctx->limits->maxfilesize && ((unsigned int) zdirent.st_size > ctx->limits->maxfilesize)) {
-		cli_dbgmsg("Zip: %s: Size exceeded (%d, max: %ld)\n", zdirent.d_name, zdirent.st_size, ctx->limits->maxfilesize);
+		cli_dbgmsg("Zip: %s: Size exceeded (%u, max: %lu)\n", zdirent.d_name, zdirent.st_size, ctx->limits->maxfilesize);
 		/* ret = CL_EMAXSIZE; */
 		if(BLOCKMAX) {
 		    *ctx->virname = "Zip.ExceededFileSize";
@@ -468,7 +468,7 @@ static int cli_scanzip(int desc, cli_ctx *ctx, off_t sfx_offset, uint32_t *sfx_c
 	    }
 
 	    if(ctx->limits->maxfiles && (files > ctx->limits->maxfiles)) {
-		cli_dbgmsg("Zip: Files limit reached (max: %d)\n", ctx->limits->maxfiles);
+		cli_dbgmsg("Zip: Files limit reached (max: %u)\n", ctx->limits->maxfiles);
 		if(BLOCKMAX) {
 		    *ctx->virname = "Zip.ExceededFilesLimit";
 		    ret = CL_VIRUS;
@@ -517,7 +517,7 @@ static int cli_scanzip(int desc, cli_ctx *ctx, off_t sfx_offset, uint32_t *sfx_c
 
 	    if(!encrypted) {
 		if(size != zdirent.st_size) {
-		    cli_dbgmsg("Zip: Incorrectly decompressed (%d != %d)\n", size, zdirent.st_size);
+		    cli_dbgmsg("Zip: Incorrectly decompressed (%lu != %lu)\n", size, (unsigned long int) zdirent.st_size);
 		    if(zfp->bf[0] == -1) {
 			ret = CL_EZIP;
 			break;
@@ -614,7 +614,7 @@ static int cli_scangzip(int desc, cli_ctx *ctx)
     fd = fileno(tmp);
 
     if(!(buff = (char *) cli_malloc(FILEBUFF))) {
-	cli_dbgmsg("GZip: Unable to malloc %d bytes.\n", FILEBUFF);
+	cli_dbgmsg("GZip: Unable to malloc %u bytes.\n", FILEBUFF);
 	gzclose(gd);
 	fclose(tmp);
 	if(!cli_leavetemps_flag)
@@ -883,7 +883,7 @@ static int cli_scanmscab(int desc, cli_ctx *ctx, off_t sfx_offset)
 	files++;
 
 	if(ctx->limits && ctx->limits->maxfilesize && (file->length > ctx->limits->maxfilesize)) {
-	    cli_dbgmsg("CAB: %s: Size exceeded (%u, max: %u)\n", file->name, file->length, ctx->limits->maxfilesize);
+	    cli_dbgmsg("CAB: %s: Size exceeded (%u, max: %lu)\n", file->name, file->length, ctx->limits->maxfilesize);
 	    if(BLOCKMAX) {
 		*ctx->virname = "CAB.ExceededFileSize";
 		cab_free(&cab);
@@ -1194,7 +1194,7 @@ static int cli_scanhtml(int desc, cli_ctx *ctx)
         return CL_ETMPDIR;
     }
 
-    html_normalise_fd(desc, tempname, NULL);
+    html_normalise_fd(desc, tempname, NULL, ctx->dconf);
     snprintf(fullname, 1024, "%s/comment.html", tempname);
     fd = open(fullname, O_RDONLY|O_BINARY);
     if (fd >= 0) {
@@ -1628,7 +1628,7 @@ static int cli_scanmail(int desc, cli_ctx *ctx)
 	int ret;
 
 
-    cli_dbgmsg("Starting cli_scanmail(), mrec == %d, arec == %d\n", ctx->mrec, ctx->arec);
+    cli_dbgmsg("Starting cli_scanmail(), mrec == %u, arec == %u\n", ctx->mrec, ctx->arec);
 
     /* generate the temporary directory */
     dir = cli_gentemp(NULL);
@@ -1657,17 +1657,84 @@ static int cli_scanmail(int desc, cli_ctx *ctx)
     return ret;
 }
 
-static int cli_scanraw(int desc, cli_ctx *ctx, cli_file_t type)
+static int cli_scanembpe(int desc, cli_ctx *ctx)
+{
+	int fd, bytes, ret = CL_CLEAN;
+	unsigned long int size = 0;
+	char buff[512];
+	char *tmpname;
+
+
+    tmpname = cli_gentemp(NULL);
+    if(!tmpname)
+	return CL_EMEM;
+
+    if((fd = open(tmpname, O_RDWR|O_CREAT|O_TRUNC|O_BINARY, S_IRWXU)) < 0) {
+	cli_errmsg("cli_scanembpe: Can't create file %s\n", tmpname);
+	free(tmpname);
+	return CL_EIO;
+    }
+
+    while((bytes = read(desc, buff, sizeof(buff))) > 0) {
+	size += bytes;
+
+	if(ctx->limits && ctx->limits->maxfilesize && (size + sizeof(buff) > ctx->limits->maxfilesize)) {
+	    cli_dbgmsg("cli_scanembpe: Size exceeded (stopped at %lu, max: %lu)\n", size, ctx->limits->maxfilesize);
+	    /* BLOCKMAX should be ignored here */
+	    break;
+	}
+
+	if(cli_writen(fd, buff, bytes) != bytes) {
+	    cli_dbgmsg("cli_scanembpe: Can't write to temporary file\n");
+	    close(fd);
+	    if(!cli_leavetemps_flag)
+		unlink(tmpname);
+	    free(tmpname);	
+	    return CL_EIO;
+	}
+    }
+
+    if(fsync(fd) == -1) {
+	cli_dbgmsg("cli_scanembpe: Can't synchronise descriptor %d\n", fd);
+	close(fd);
+	if(!cli_leavetemps_flag)
+	    unlink(tmpname);
+	free(tmpname);	
+	return CL_EFSYNC;
+    }
+
+    lseek(fd, 0, SEEK_SET);
+    if((ret = cli_magic_scandesc(fd, ctx)) == CL_VIRUS) {
+	cli_dbgmsg("cli_scanembpe: Infected with %s\n", *ctx->virname);
+	close(fd);
+	if(!cli_leavetemps_flag)
+	    unlink(tmpname);
+	free(tmpname);	
+	return CL_VIRUS;
+    }
+
+    close(fd);
+    if(!cli_leavetemps_flag)
+	unlink(tmpname);
+    free(tmpname);
+
+    /* intentionally ignore possible errors from cli_magic_scandesc */
+    return CL_CLEAN;
+}
+
+static int cli_scanraw(int desc, cli_ctx *ctx, cli_file_t type, uint8_t typercg)
 {
 	int ret = CL_CLEAN, nret = CL_CLEAN;
-	unsigned short ftrec;
+	uint8_t ftrec = 0, break_loop = 0;
 	struct cli_matched_type *ftoffset = NULL, *fpt;
 	uint32_t lastzip, lastrar;
+	struct cli_exe_info peinfo;
 
 
-    switch(type) {
+    if(typercg) switch(type) {
 	case CL_TYPE_UNKNOWN_TEXT:
 	case CL_TYPE_MSEXE:
+	case CL_TYPE_ZIP:
 	    ftrec = 1;
 	    break;
 	default:
@@ -1682,13 +1749,83 @@ static int cli_scanraw(int desc, cli_ctx *ctx, cli_file_t type)
     ret = cli_scandesc(desc, ctx, ftrec, type, 0, &ftoffset);
 
     if(ret >= CL_TYPENO) {
-	lseek(desc, 0, SEEK_SET);
 
-	nret = cli_scandesc(desc, ctx, 0, ret, 1, NULL);
-	if(nret == CL_VIRUS)
-	    cli_dbgmsg("%s found in descriptor %d when scanning file type %u\n", *ctx->virname, desc, ret);
+	if(type == CL_TYPE_UNKNOWN_TEXT) {
+	    lseek(desc, 0, SEEK_SET);
+
+	    nret = cli_scandesc(desc, ctx, 0, ret, 1, NULL);
+	    if(nret == CL_VIRUS)
+		cli_dbgmsg("%s found in descriptor %d when scanning file type %u\n", *ctx->virname, desc, ret);
+	}
+
+	if(nret != CL_VIRUS && (type == CL_TYPE_MSEXE || type == CL_TYPE_ZIP)) {
+	    lastzip = lastrar = 0xdeadbeef;
+	    fpt = ftoffset;
+	    while(fpt) {
+		switch(fpt->type) {
+		    case CL_TYPE_RARSFX:
+			if(SCAN_ARCHIVE && type == CL_TYPE_MSEXE && (DCONF_ARCH & ARCH_CONF_RAR)) {
+			    cli_dbgmsg("RAR-SFX signature found at %u\n", (unsigned int) fpt->offset);
+			    nret = cli_scanrar(desc, ctx, fpt->offset, &lastrar);
+			}
+			break;
+
+		    case CL_TYPE_ZIPSFX:
+			if(SCAN_ARCHIVE && type == CL_TYPE_MSEXE && (DCONF_ARCH & ARCH_CONF_ZIP) && fpt->offset) {
+			    cli_dbgmsg("ZIP-SFX signature found at %u\n", (unsigned int) fpt->offset);
+			    nret = cli_scanzip(desc, ctx, fpt->offset, &lastzip);
+			}
+			break;
+
+		    case CL_TYPE_CABSFX:
+			if(SCAN_ARCHIVE && type == CL_TYPE_MSEXE && (DCONF_ARCH & ARCH_CONF_CAB)) {
+			    cli_dbgmsg("CAB-SFX signature found at %u\n", (unsigned int) fpt->offset);
+			    nret = cli_scanmscab(desc, ctx, fpt->offset);
+			}
+			break;
+
+		    case CL_TYPE_NULSFT:
+		        if(SCAN_ARCHIVE && type == CL_TYPE_MSEXE && (DCONF_ARCH & ARCH_CONF_NSIS) && fpt->offset > 4) {
+			    cli_dbgmsg("NSIS signature found at %u\n", (unsigned int) fpt->offset-4);
+			    nret = cli_scannulsft(desc, ctx, fpt->offset - 4);
+			}
+			break;
+
+		    case CL_TYPE_MSEXE:
+			if(SCAN_PE && ctx->dconf->pe && fpt->offset) {
+			    cli_dbgmsg("PE signature found at %u\n", (unsigned int) fpt->offset);
+			    memset(&peinfo, 0, sizeof(struct cli_exe_info));
+			    peinfo.offset = fpt->offset;
+			    lseek(desc, fpt->offset, SEEK_SET);
+			    if(cli_peheader(desc, &peinfo) == 0) {
+				cli_dbgmsg("*** Detected embedded PE file ***\n");
+				if(peinfo.section)
+				    free(peinfo.section);
+
+				lseek(desc, fpt->offset, SEEK_SET);
+				nret = cli_scanembpe(desc, ctx);
+				break_loop = 1; /* we can stop here and other
+						 * embedded executables will
+						 * be found recursively
+						 * through the above call
+						 */
+			    }
+			}
+			break;
+
+		    default:
+			cli_warnmsg("cli_scanraw: Type %u not handled in fpt loop\n", fpt->type);
+		}
+
+		if(nret == CL_VIRUS || break_loop)
+		    break;
+
+		fpt = fpt->next;
+	    }
+	}
 
 	ret == CL_TYPE_MAIL ? ctx->mrec++ : ctx->arec++;
+
 	if(nret != CL_VIRUS) switch(ret) {
 	    case CL_TYPE_HTML:
 		if(SCAN_HTML && type == CL_TYPE_UNKNOWN_TEXT && (DCONF_DOC & DOC_CONF_HTML))
@@ -1700,34 +1837,6 @@ static int cli_scanraw(int desc, cli_ctx *ctx, cli_file_t type)
 		    nret = cli_scanmail(desc, ctx);
 		break;
 
-	    case CL_TYPE_RARSFX:
-	    case CL_TYPE_ZIPSFX:
-	    case CL_TYPE_CABSFX:
-		if(type == CL_TYPE_MSEXE) {
-		    if(SCAN_ARCHIVE) {
-			lastzip = lastrar = 0xdeadbeef;
-			fpt = ftoffset;
-			while(fpt) {
-			    if(fpt->type == CL_TYPE_RARSFX && (DCONF_ARCH & ARCH_CONF_RAR)) {
-				cli_dbgmsg("RAR-SFX signature found at %d\n", fpt->offset);
-				if((nret = cli_scanrar(desc, ctx, fpt->offset, &lastrar)) == CL_VIRUS)
-				    break;
-			    } else if(fpt->type == CL_TYPE_ZIPSFX && (DCONF_ARCH & ARCH_CONF_ZIP)) {
-				cli_dbgmsg("ZIP-SFX signature found at %d\n", fpt->offset);
-				if((nret = cli_scanzip(desc, ctx, fpt->offset, &lastzip)) == CL_VIRUS)
-				    break;
-			    } else if(fpt->type == CL_TYPE_CABSFX && (DCONF_ARCH & ARCH_CONF_CAB)) {
-				cli_dbgmsg("CAB-SFX signature found at %d\n", fpt->offset);
-				if((nret = cli_scanmscab(desc, ctx, fpt->offset)) == CL_VIRUS)
-				    break;
-			    }
-
-			    fpt = fpt->next;
-			}
-		    }
-		}
-		break;
-
 	    default:
 		break;
 	}
@@ -1752,6 +1861,7 @@ int cli_magic_scandesc(int desc, cli_ctx *ctx)
 	int ret = CL_CLEAN;
 	cli_file_t type;
 	struct stat sb;
+	uint8_t typercg = 1;
 
 
     if(fstat(desc, &sb) == -1) {
@@ -1760,7 +1870,7 @@ int cli_magic_scandesc(int desc, cli_ctx *ctx)
     }
 
     if(sb.st_size <= 5) {
-	cli_dbgmsg("Small data (%d bytes)\n", sb.st_size);
+	cli_dbgmsg("Small data (%u bytes)\n", (unsigned int) sb.st_size);
 	return CL_CLEAN;
     }
 
@@ -1778,7 +1888,7 @@ int cli_magic_scandesc(int desc, cli_ctx *ctx)
 
     if(SCAN_ARCHIVE && ctx->limits && ctx->limits->maxreclevel)
 	if(ctx->arec > ctx->limits->maxreclevel) {
-	    cli_dbgmsg("Archive recursion limit exceeded (arec == %d).\n", ctx->arec);
+	    cli_dbgmsg("Archive recursion limit exceeded (arec == %u).\n", ctx->arec);
 	    if(BLOCKMAX) {
 		*ctx->virname = "Archive.ExceededRecursionLimit";
 		return CL_VIRUS;
@@ -1788,7 +1898,7 @@ int cli_magic_scandesc(int desc, cli_ctx *ctx)
 
     if(SCAN_MAIL)
 	if(ctx->mrec > MAX_MAIL_RECURSION) {
-	    cli_dbgmsg("Mail recursion level exceeded (mrec == %d).\n", ctx->mrec);
+	    cli_dbgmsg("Mail recursion level exceeded (mrec == %u).\n", ctx->mrec);
 	    /* return CL_EMAXREC; */
 	    return CL_CLEAN;
 	}
@@ -1798,7 +1908,7 @@ int cli_magic_scandesc(int desc, cli_ctx *ctx)
     lseek(desc, 0, SEEK_SET);
 
     if(type != CL_TYPE_DATA && ctx->engine->sdb) {
-	if((ret = cli_scanraw(desc, ctx, type)) == CL_VIRUS)
+	if((ret = cli_scanraw(desc, ctx, type, 0)) == CL_VIRUS)
 	    return CL_VIRUS;
 	lseek(desc, 0, SEEK_SET);
     }
@@ -1828,6 +1938,11 @@ int cli_magic_scandesc(int desc, cli_ctx *ctx)
 #endif
 	    break;
 
+        case CL_TYPE_NULSFT:
+	    if(SCAN_ARCHIVE)
+		ret = cli_scannulsft(desc, ctx, 0);
+	    break;
+
 	case CL_TYPE_MSSZDD:
 	    if(SCAN_ARCHIVE && (DCONF_ARCH & ARCH_CONF_SZDD))
 		ret = cli_scanszdd(desc, ctx);
@@ -1946,8 +2061,15 @@ int cli_magic_scandesc(int desc, cli_ctx *ctx)
 
     type == CL_TYPE_MAIL ? ctx->mrec-- : ctx->arec--;
 
+    if(type == CL_TYPE_ZIP && SCAN_ARCHIVE && (DCONF_ARCH & ARCH_CONF_ZIP)) {
+	if(sb.st_size > 1048576) {
+	    cli_dbgmsg("cli_magic_scandesc: Not checking for embedded PEs (zip file > 1 MB)\n");
+	    typercg = 0;
+	}
+    }
+
     if(type != CL_TYPE_DATA && ret != CL_VIRUS && !ctx->engine->sdb) {
-	if(cli_scanraw(desc, ctx, type) == CL_VIRUS)
+	if(cli_scanraw(desc, ctx, type, typercg) == CL_VIRUS)
 	    return CL_VIRUS;
     }
 
@@ -1978,6 +2100,7 @@ int cli_magic_scandesc(int desc, cli_ctx *ctx)
 int cl_scandesc(int desc, const char **virname, unsigned long int *scanned, const struct cl_engine *engine, const struct cl_limits *limits, unsigned int options)
 {
     cli_ctx ctx;
+    int rc;
 
     memset(&ctx, '\0', sizeof(cli_ctx));
     ctx.engine = engine;
@@ -1985,9 +2108,13 @@ int cl_scandesc(int desc, const char **virname, unsigned long int *scanned, cons
     ctx.limits = limits;
     ctx.scanned = scanned;
     ctx.options = options;
+    ctx.found_possibly_unwanted = 0;
     ctx.dconf = (struct cli_dconf *) engine->dconf;
 
-    return cli_magic_scandesc(desc, &ctx);
+    rc = cli_magic_scandesc(desc, &ctx);
+    if(rc == CL_CLEAN && ctx.found_possibly_unwanted)
+    	rc = CL_VIRUS;
+    return rc;
 }
 
 static int cli_scanfile(const char *filename, cli_ctx *ctx)
