@@ -1,11 +1,11 @@
 /*
  *  Copyright (C) 2002 - 2005 Tomasz Kojm <tkojm@clamav.net>
  *  cli_strrcpy(): Copyright (C) 2002 Nigel Horne <njh@bandsman.co.uk>
+ *  cli_strtokenize(): Copyright (C) 2007 Edwin Torok <edwin@clamav.net>
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -28,10 +28,12 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
+#include <sys/types.h>
 
 #include "clamav.h"
 #include "others.h"
-#include "defaults.h"
+#include "matcher.h"
+#include "cltypes.h"
 
 static int cli_hex2int(int c)
 {
@@ -51,30 +53,53 @@ static int cli_hex2int(int c)
     return -1;
 }
 
-short int *cli_hex2si(const char *hex)
+uint16_t *cli_hex2ui(const char *hex)
 {
-	short int *str, *ptr, val, c;
-	int i, len;
+	uint16_t *str, *ptr, val;
+	unsigned int i, len;
+	int c;
 
 
     len = strlen(hex);
 
     if(len % 2 != 0) {
-	cli_errmsg("cli_hex2si(): Malformed hexstring: %s (length: %d)\n", hex, len);
+	cli_errmsg("cli_hex2si(): Malformed hexstring: %s (length: %u)\n", hex, len);
 	return NULL;
     }
 
-    str = cli_calloc((len / 2) + 1, sizeof(short int));
+    str = cli_calloc((len / 2) + 1, sizeof(uint16_t));
     if(!str)
 	return NULL;
 
     ptr = str;
 
     for(i = 0; i < len; i += 2) {
-	if(hex[i] == '?') {
-	    val = CLI_IGN;
-	} else if(hex[i] == '@') {
-	    val = CLI_ALT;
+	val = 0;
+
+	if(hex[i] == '?' && hex[i + 1] == '?') {
+	    val |= CLI_MATCH_IGNORE;
+
+	} else if(hex[i + 1] == '?') {
+	    if((c = cli_hex2int(hex[i])) >= 0) {
+		val = c << 4;
+	    } else {
+		free(str);
+		return NULL;
+	    }
+	    val |= CLI_MATCH_NIBBLE_HIGH;
+
+	} else if(hex[i] == '?') {
+	    if((c = cli_hex2int(hex[i + 1])) >= 0) {
+		val = c;
+	    } else {
+		free(str);
+		return NULL;
+	    }
+	    val |= CLI_MATCH_NIBBLE_LOW;
+
+	} else if(hex[i] == '(') {
+	    val |= CLI_MATCH_ALTERNATIVE;
+
 	} else {
 	    if((c = cli_hex2int(hex[i])) >= 0) {
 		val = c;
@@ -89,6 +114,7 @@ short int *cli_hex2si(const char *hex)
 		return NULL;
 	    }
 	}
+
 	*ptr++ = val;
     }
 
@@ -370,3 +396,22 @@ char *cli_strrcpy(char *dest, const char *source) /* by NJH */
 
     return --dest;
 }
+
+void cli_strtokenize(char *buffer, const char delim, const size_t token_count, const char **tokens)
+{
+	size_t tokens_found;
+
+
+    for(tokens_found = 0; tokens_found < token_count; ) {
+	tokens[tokens_found++] = buffer;
+	buffer = strchr(buffer, delim);
+	if(buffer) {
+	    *buffer++ = '\0';
+	} else {
+	    while(tokens_found < token_count)
+		tokens[tokens_found++] = NULL;
+
+	    return;
+	}
+    }
+}
