@@ -873,10 +873,10 @@ static int add_vm_code(unpack_data_t *unpack_data, unsigned int first_byte,
 			return FALSE;
 		}	
 		unpack_data->old_filter_lengths_size++;
-		unpack_data->old_filter_lengths = (int *) cli_realloc(unpack_data->old_filter_lengths,
+		unpack_data->old_filter_lengths = (int *) cli_realloc2(unpack_data->old_filter_lengths,
 				sizeof(int) * unpack_data->old_filter_lengths_size);
 		if(!unpack_data->old_filter_lengths) {
-		    cli_dbgmsg("unrar: add_vm_code: cli_realloc failed for unpack_data->old_filter_lengths\n");
+		    cli_dbgmsg("unrar: add_vm_code: cli_realloc2 failed for unpack_data->old_filter_lengths\n");
 		    return FALSE;
 		}
 		unpack_data->old_filter_lengths[unpack_data->old_filter_lengths_size-1] = 0;
@@ -1006,10 +1006,10 @@ static int add_vm_code(unpack_data_t *unpack_data, unsigned int first_byte,
 		cur_size = stack_filter->prg.global_size;
 		if (cur_size < data_size+VM_FIXEDGLOBALSIZE) {
 			stack_filter->prg.global_size += data_size+VM_FIXEDGLOBALSIZE-cur_size;
-			stack_filter->prg.global_data = cli_realloc(stack_filter->prg.global_data,
+			stack_filter->prg.global_data = cli_realloc2(stack_filter->prg.global_data,
 				stack_filter->prg.global_size);
 			if(!stack_filter->prg.global_data) {
-			    cli_dbgmsg("unrar: add_vm_code: cli_realloc failed for stack_filter->prg.global_data\n");
+			    cli_dbgmsg("unrar: add_vm_code: cli_realloc2 failed for stack_filter->prg.global_data\n");
 			    return FALSE;
 			}
 		}
@@ -1615,7 +1615,7 @@ int cli_unrar_extract_next(rar_state_t* state,const char* dirname)
 	} else if(state->file_header->flags & (LHD_SPLIT_BEFORE | LHD_SPLIT_AFTER)) {
 	        cli_dbgmsg("Skipping split file\n");
 
-	} else if((state->main_hdr->flags & MHD_VOLUME) && (state->main_hdr->flags && MHD_SOLID)) {
+	} else if((state->main_hdr->flags & MHD_VOLUME) && (state->main_hdr->flags & MHD_SOLID)) {
 	        cli_dbgmsg("Skipping file inside multi-volume solid archive\n");
 
 	} else /*if (file_header->unpack_size)*/ {
@@ -1650,7 +1650,7 @@ int cli_unrar_extract_next(rar_state_t* state,const char* dirname)
 			cli_dbgmsg("Computed File CRC: 0x%x\n", state->unpack_data->unp_crc^0xffffffff);
 			if (state->unpack_data->unp_crc != 0xffffffff) {
 				if (state->file_header->file_crc != (state->unpack_data->unp_crc^0xffffffff)) {
-					cli_warnmsg("RAR CRC error. Please report the bug at http://bugs.clamav.net/\n");
+					cli_warnmsg("RAR CRC error. If the file is not corrupted, please report at http://bugs.clamav.net/\n");
 				}
 			}
 			if (!retval) {
