@@ -41,6 +41,8 @@ static	char	const	rcsid[] = "$Id: untar.c,v 1.35 2007/02/12 20:46:09 njh Exp $";
 #include "clamav.h"
 #include "others.h"
 #include "untar.h"
+#include "mbox.h"
+#include "blob.h"
 
 #define BLOCKSIZE 512
 
@@ -194,7 +196,7 @@ cli_untar(const char *dir, int desc, unsigned int posix, const struct cl_limits
 			 * see also fileblobSetFilename()
 			 * TODO: check if the suffix needs to be put back
 			 */
-			cli_sanitise_filename(name);
+			sanitiseName(name);
 			suffix = strrchr(name, '.');
 			if(suffix == NULL)
 				suffix = "";
