@@ -13,10 +13,17 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  *
  * Change History:
  * $Log: untar.h,v $
+ * Revision 1.5  2006/12/22 18:29:13  njh
+ * Recommit fix for bug 153
+ *
+ * Revision 1.4  2006/04/09 19:59:28  kojm
+ * update GPL headers with new address for FSF
+ *
  * Revision 1.3  2005/03/22 21:26:27  kojm
  * add support for old fashioned tar archives
  *
@@ -27,12 +34,4 @@
  * First draft
  *
  */
-
-#ifndef __UNTAR_H
-#define __UNTAR_H
-
-#include "clamav.h"
-
 int cli_untar(const char *dir, int desc, unsigned int posix, const struct cl_limits *limits);
-
-#endif
