@@ -1,14 +1,14 @@
 /*
- *  Copyright (C) 2003 - 2006 Tomasz Kojm <tkojm@clamav.net>
+ *  Copyright (C) 2003 - 2005 Tomasz Kojm <tkojm@clamav.net>
+ *	      (C) 2006 Sensory Networks, Inc.
  *
  *  The code of this module was based on zziplib 0.12.83:
  *  (c) 1999 - 2002 Guido Draheim <guidod@gmx.de>, published under
  *  the Lesser GNU General Public License
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  it under the terms of the GNU General Public License version 2 as
+ *  published by the Free Software Foundation.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -110,7 +110,7 @@ static int __zip_find_disk_trailer(int fd, off_t filesize, struct zip_disk_trail
 	}
 
         if(cli_readn(fd, buf, (size_t) bufsize) < (ssize_t) bufsize) {
-	    cli_errmsg("Unzip: __zip_find_disk_trailer: Can't read %d bytes\n", bufsize);
+	    cli_errmsg("Unzip: __zip_find_disk_trailer: Can't read %u bytes\n", (unsigned int) bufsize);
 	    free(buf);
 	    return CL_EIO;
 	}
@@ -141,7 +141,7 @@ static int __zip_find_disk_trailer(int fd, off_t filesize, struct zip_disk_trail
 			}
 
 			if(cli_readn(fd, &dirent, sizeof(dirent)) < __sizeof(dirent)) {
-			    cli_errmsg("Unzip: __zip_find_disk_trailer: Can't read %d bytes\n", bufsize);
+			    cli_errmsg("Unzip: __zip_find_disk_trailer: Can't read %u bytes\n", (unsigned int) bufsize);
 			    free(buf);
 			    return CL_EIO;
 			}
